"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
var chalk_1 = __importDefault(require("chalk"));
var gulp_1 = __importDefault(require("gulp"));
var _ = __importStar(require("lodash"));
var shell = __importStar(require("shelljs"));
var rimraf_1 = __importDefault(require("rimraf"));
var fs_extra_1 = __importDefault(require("fs-extra"));
var gulpTasks_json_1 = require("./gulpTasks.json");
var package_json_1 = __importDefault(require("./package.json"));
shell.config.silent = true;
shell.config.verbose = false;
var showVariables = function () {
    var shown = ["NODE_ENV"];
    console.log(chalk_1.default.magenta("process.env variables: ") + chalk_1.default.cyan("{"));
    _.mapValues(process.env, function (value, key) {
        if (_.includes(shown, key)) {
            console.log(chalk_1.default.blue("    " + key + ": ") + chalk_1.default.gray(value || "undefined"));
        }
    });
    console.log(chalk_1.default.cyan("}"));
};
gulp_1.default.task("init", function (done) {
    done();
});
gulp_1.default.task("init:dev", gulp_1.default.series("init", function (done) {
    process.env.NODE_ENV = "development";
    showVariables();
    done();
}));
gulp_1.default.task("init:prod", gulp_1.default.series("init", function (done) {
    process.env.NODE_ENV = "production";
    showVariables();
    done();
}));
var _a = package_json_1.default.version.split("."), major = _a[0], minor = _a[1], patch = _a[2];
var newVersion;
gulp_1.default.task(gulpTasks_json_1.COMPILE.task, gulp_1.default.series("init:prod", function (done) {
    console.log(chalk_1.default.blue("Compiling..."));
    rimraf_1.default.sync("./dist");
    shell.exec("tsc");
    console.log(chalk_1.default.green("Compiled!"));
    done();
}));
gulp_1.default.task(gulpTasks_json_1.BUMP_START.task, gulp_1.default.series(function (done) {
    console.log(chalk_1.default.blue("Bumping version..."));
    done();
}));
gulp_1.default.task(gulpTasks_json_1.BUMP_END.task, gulp_1.default.series(function (done) {
    var newPkg = Object.assign({}, package_json_1.default, { version: newVersion });
    fs_extra_1.default.writeFileSync("./package.json", JSON.stringify(newPkg, null, 4));
    console.log(chalk_1.default.green("Package Version Updated"), chalk_1.default.bold.white(package_json_1.default.version), chalk_1.default.green("->"), chalk_1.default.bold.white(newVersion));
    done();
}));
gulp_1.default.task(gulpTasks_json_1.BUMP_PATCH.task, gulp_1.default.series(gulpTasks_json_1.BUMP_START.task, function (done) {
    newVersion = major + "." + minor + "." + (parseInt(patch, 10) + 1);
    done();
}, gulpTasks_json_1.BUMP_END.task));
gulp_1.default.task(gulpTasks_json_1.BUMP_MINOR.task, gulp_1.default.series(gulpTasks_json_1.BUMP_START.task, function (done) {
    newVersion = major + "." + (parseInt(minor, 10) + 1) + "." + 0;
    done();
}, gulpTasks_json_1.BUMP_END.task));
gulp_1.default.task(gulpTasks_json_1.BUMP_MAJOR.task, gulp_1.default.series(gulpTasks_json_1.BUMP_START.task, function (done) {
    newVersion = parseInt(major, 10) + 1 + "." + 0 + "." + 0;
    done();
}, gulpTasks_json_1.BUMP_END.task));
gulp_1.default.task(gulpTasks_json_1.PUBLISH_DONE.task, gulp_1.default.series(function (done) {
    console.log(chalk_1.default.green("✔ succesfully published tchin-backend"), chalk_1.default.white("( https://www.npmjs.com/package/tchin-backend )"));
    rimraf_1.default.sync("./dist");
    done();
}));
gulp_1.default.task(gulpTasks_json_1.PUBLISH.task, gulp_1.default.series(gulpTasks_json_1.BUMP_PATCH.task, gulpTasks_json_1.COMPILE.task, function (done) {
    shell.exec("npm publish");
    done();
}, gulpTasks_json_1.PUBLISH_DONE.task));
gulp_1.default.task(gulpTasks_json_1.PUBLISH_MINOR.task, gulp_1.default.series(gulpTasks_json_1.BUMP_MINOR.task, gulpTasks_json_1.COMPILE.task, function (done) {
    shell.exec("npm publish");
    done();
}, gulpTasks_json_1.PUBLISH_DONE.task));
gulp_1.default.task(gulpTasks_json_1.PUBLISH_MAJOR.task, gulp_1.default.series(gulpTasks_json_1.BUMP_MAJOR.task, gulpTasks_json_1.COMPILE.task, function (done) {
    shell.exec("npm publish");
    done();
}, gulpTasks_json_1.PUBLISH_DONE.task));
//# sourceMappingURL=gulpfile.js.map